==> maven-scm-2.0.1-source-release.zip: maven-scm-2.0.1/maven-scm-api/src/main/java/org/apache/maven/scm/command/checkin/AbstractCheckInCommand.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.scm.command.checkin;

import org.apache.maven.scm.CommandParameter;
import org.apache.maven.scm.CommandParameters;
import org.apache.maven.scm.ScmException;
import org.apache.maven.scm.ScmFileSet;
import org.apache.maven.scm.ScmResult;
import org.apache.maven.scm.ScmVersion;
import org.apache.maven.scm.command.AbstractCommand;
import org.apache.maven.scm.provider.ScmProviderRepository;

/**
 * @author <a href="mailto:evenisse@apache.org">Emmanuel Venisse</a>
 * @author <a href="mailto:trygvis@inamo.no">Trygve Laugst&oslash;l</a>
 * @author Olivier Lamy
 *
 */
public abstract class AbstractCheckInCommand extends AbstractCommand {
    public static final String NAME = "check-in";

    protected abstract CheckInScmResult executeCheckInCommand(
            ScmProviderRepository repository, ScmFileSet fileSet, String message, ScmVersion scmVersion)
            throws ScmException;

    public ScmResult executeCommand(ScmProviderRepository repository, ScmFileSet fileSet, CommandParameters parameters)
            throws ScmException {
        String message = parameters.getString(CommandParameter.MESSAGE);

        ScmVersion scmVersion = parameters.getScmVersion(CommandParameter.SCM_VERSION, null);

        return executeCheckInCommand(repository, fileSet, message, scmVersion);
    }
}

==> maven-scm-2.2.1-source-release.zip: maven-scm-2.2.1/maven-scm-api/src/main/java/org/apache/maven/scm/command/checkin/AbstractCheckInCommand.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.scm.command.checkin;

import org.apache.maven.scm.CommandParameter;
import org.apache.maven.scm.CommandParameters;
import org.apache.maven.scm.CommandParameters.SignOption;
import org.apache.maven.scm.ScmException;
import org.apache.maven.scm.ScmFileSet;
import org.apache.maven.scm.ScmResult;
import org.apache.maven.scm.ScmVersion;
import org.apache.maven.scm.command.AbstractCommand;
import org.apache.maven.scm.provider.ScmProviderRepository;

/**
 * @author <a href="mailto:evenisse@apache.org">Emmanuel Venisse</a>
 * @author <a href="mailto:trygvis@inamo.no">Trygve Laugst&oslash;l</a>
 * @author Olivier Lamy
 */
public abstract class AbstractCheckInCommand extends AbstractCommand {
    public static final String NAME = "check-in";

    protected CheckInScmResult executeCheckInCommand(
            ScmProviderRepository repository,
            ScmFileSet fileSet,
            String message,
            ScmVersion scmVersion,
            SignOption signOption)
            throws ScmException {
        return executeCheckInCommand(repository, fileSet, message, scmVersion);
    }

    /**
     * @param repository
     * @param fileSet
     * @param message
     * @param scmVersion
     * @return
     * @throws ScmException
     * @deprecated use {@link #executeCheckInCommand(ScmProviderRepository, ScmFileSet, String, ScmVersion, SignOption)}
     */
    @Deprecated
    protected abstract CheckInScmResult executeCheckInCommand(
            ScmProviderRepository repository, ScmFileSet fileSet, String message, ScmVersion scmVersion)
            throws ScmException;

    public ScmResult executeCommand(ScmProviderRepository repository, ScmFileSet fileSet, CommandParameters parameters)
            throws ScmException {
        String message = parameters.getString(CommandParameter.MESSAGE);

        ScmVersion scmVersion = parameters.getScmVersion(CommandParameter.SCM_VERSION, null);
        SignOption signOption = parameters.getSignOption(CommandParameter.SIGN_OPTION);
        return executeCheckInCommand(repository, fileSet, message, scmVersion, signOption);
    }
}
